"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VpcLatticeEnvelope = void 0;
const errors_js_1 = require("../errors.js");
const index_js_1 = require("../schemas/index.js");
const envelope_js_1 = require("./envelope.js");
/**
 * Amazon VPC Lattice envelope to extract data within body key
 */
exports.VpcLatticeEnvelope = {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelope_js_1.envelopeDiscriminator]: 'object',
    parse(data, schema) {
        try {
            return index_js_1.VpcLatticeSchema.extend({
                body: schema,
            }).parse(data).body;
        }
        catch (error) {
            throw new errors_js_1.ParseError('Failed to parse VPC Lattice body', {
                cause: error,
            });
        }
    },
    safeParse(data, schema) {
        const result = index_js_1.VpcLatticeSchema.extend({
            body: schema,
        }).safeParse(data);
        if (!result.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse VPC Lattice body', {
                    cause: result.error,
                }),
                originalEvent: data,
            };
        }
        return {
            success: true,
            data: result.data.body,
        };
    },
};
