import { z } from 'zod';
/**
 *
 * Zod schema for AWS Transfer Family events.
 *
 * @example
 * ```json
 * {
 *   "username": "testUser",
 *   "password": "testPass",
 *   "protocol": "SFTP",
 *   "serverId": "s-abcd123456",
 *   "sourceIp": "192.168.0.100"
 * }
 * ```
 *
 * TransferFamilySchema validates events coming from AWS Transfer Family.
 *
 */
declare const TransferFamilySchema: z.ZodObject<{
    username: z.ZodString;
    password: z.ZodString;
    protocol: z.ZodString;
    serverId: z.ZodString;
    sourceIp: z.ZodString;
}, "strip", z.ZodTypeAny, {
    sourceIp: string;
    protocol: string;
    username: string;
    password: string;
    serverId: string;
}, {
    sourceIp: string;
    protocol: string;
    username: string;
    password: string;
    serverId: string;
}>;
export { TransferFamilySchema };
//# sourceMappingURL=transfer-family.d.ts.map