"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransferFamilySchema = void 0;
const zod_1 = require("zod");
/**
 *
 * Zod schema for AWS Transfer Family events.
 *
 * @example
 * ```json
 * {
 *   "username": "testUser",
 *   "password": "testPass",
 *   "protocol": "SFTP",
 *   "serverId": "s-abcd123456",
 *   "sourceIp": "192.168.0.100"
 * }
 * ```
 *
 * TransferFamilySchema validates events coming from AWS Transfer Family.
 *
 */
const TransferFamilySchema = zod_1.z.object({
    username: zod_1.z.string(),
    password: zod_1.z.string(),
    protocol: zod_1.z.string(),
    serverId: zod_1.z.string(),
    sourceIp: zod_1.z.string().ip(),
});
exports.TransferFamilySchema = TransferFamilySchema;
