import { type ZodSchema, type z } from 'zod';
import type { DynamoDBStreamEnvelopeResponse } from '../types/envelope.js';
import type { ParsedResult } from '../types/index.js';
import { envelopeDiscriminator } from './envelope.js';
/**
 * DynamoDB Stream Envelope to extract data within NewImage/OldImage
 *
 * Note: Values are the parsed models. Images' values can also be None, and
 * length of the list is the record's amount in the original event.
 */
export declare const DynamoDBStreamEnvelope: {
    /**
     * This is a discriminator to differentiate whether an envelope returns an array or an object
     * @hidden
     */
    [envelopeDiscriminator]: "array";
    parse<T extends ZodSchema>(data: unknown, schema: T): DynamoDBStreamEnvelopeResponse<z.infer<T>>[];
    safeParse<T extends ZodSchema>(data: unknown, schema: T): ParsedResult<unknown, DynamoDBStreamEnvelopeResponse<z.infer<T>>[]>;
};
//# sourceMappingURL=dynamodb.d.ts.map