import { z } from 'zod';
declare const KinesisDataStreamRecordPayload: z.ZodObject<{
    kinesisSchemaVersion: z.ZodString;
    partitionKey: z.ZodString;
    sequenceNumber: z.ZodString;
    approximateArrivalTimestamp: z.ZodNumber;
    data: z.ZodEffects<z.ZodString, any, string>;
}, "strip", z.ZodTypeAny, {
    kinesisSchemaVersion: string;
    partitionKey: string;
    sequenceNumber: string;
    approximateArrivalTimestamp: number;
    data?: any;
}, {
    data: string;
    kinesisSchemaVersion: string;
    partitionKey: string;
    sequenceNumber: string;
    approximateArrivalTimestamp: number;
}>;
declare const KinesisDataStreamRecord: z.ZodObject<{
    eventSource: z.ZodLiteral<"aws:kinesis">;
    eventVersion: z.ZodString;
    eventID: z.ZodString;
    eventName: z.ZodLiteral<"aws:kinesis:record">;
    awsRegion: z.ZodString;
    invokeIdentityArn: z.ZodString;
    eventSourceARN: z.ZodString;
    kinesis: z.ZodObject<{
        kinesisSchemaVersion: z.ZodString;
        partitionKey: z.ZodString;
        sequenceNumber: z.ZodString;
        approximateArrivalTimestamp: z.ZodNumber;
        data: z.ZodEffects<z.ZodString, any, string>;
    }, "strip", z.ZodTypeAny, {
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
        data?: any;
    }, {
        data: string;
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
    }>;
}, "strip", z.ZodTypeAny, {
    eventSource: "aws:kinesis";
    eventVersion: string;
    eventID: string;
    eventName: "aws:kinesis:record";
    awsRegion: string;
    invokeIdentityArn: string;
    eventSourceARN: string;
    kinesis: {
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
        data?: any;
    };
}, {
    eventSource: "aws:kinesis";
    eventVersion: string;
    eventID: string;
    eventName: "aws:kinesis:record";
    awsRegion: string;
    invokeIdentityArn: string;
    eventSourceARN: string;
    kinesis: {
        data: string;
        kinesisSchemaVersion: string;
        partitionKey: string;
        sequenceNumber: string;
        approximateArrivalTimestamp: number;
    };
}>;
declare const KinesisDynamoDBStreamSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
        eventSource: z.ZodLiteral<"aws:kinesis">;
        eventVersion: z.ZodString;
        eventID: z.ZodString;
        eventName: z.ZodLiteral<"aws:kinesis:record">;
        awsRegion: z.ZodString;
        invokeIdentityArn: z.ZodString;
        eventSourceARN: z.ZodString;
        kinesis: z.ZodObject<{
            kinesisSchemaVersion: z.ZodString;
            partitionKey: z.ZodString;
            sequenceNumber: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            data: z.ZodEffects<z.ZodString, any, string>;
        }, "strip", z.ZodTypeAny, {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        }, {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        }>;
    }, {
        kinesis: z.ZodObject<z.objectUtil.extendShape<{
            kinesisSchemaVersion: z.ZodString;
            partitionKey: z.ZodString;
            sequenceNumber: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            data: z.ZodEffects<z.ZodString, any, string>;
        }, {
            data: z.ZodPipeline<z.ZodEffects<z.ZodString, any, string>, z.ZodObject<Omit<z.objectUtil.extendShape<{
                eventID: z.ZodString;
                eventName: z.ZodEnum<["INSERT", "MODIFY", "REMOVE"]>;
                eventVersion: z.ZodString;
                eventSource: z.ZodLiteral<"aws:dynamodb">;
                awsRegion: z.ZodString;
                eventSourceARN: z.ZodString;
                dynamodb: z.ZodEffects<z.ZodObject<{
                    ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
                    Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
                    NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    SequenceNumber: z.ZodString;
                    SizeBytes: z.ZodNumber;
                    StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
                }, "strip", z.ZodTypeAny, {
                    Keys: Record<string, Record<string, any>>;
                    SequenceNumber: string;
                    SizeBytes: number;
                    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }, {
                    Keys: Record<string, Record<string, any>>;
                    SequenceNumber: string;
                    SizeBytes: number;
                    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }>, {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }, {
                    Keys: Record<string, Record<string, any>>;
                    SequenceNumber: string;
                    SizeBytes: number;
                    StreamViewType: "NEW_IMAGE" | "OLD_IMAGE" | "NEW_AND_OLD_IMAGES" | "KEYS_ONLY";
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }>;
                userIdentity: z.ZodOptional<z.ZodObject<{
                    type: z.ZodEnum<["Service"]>;
                    principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
                }, "strip", z.ZodTypeAny, {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                }, {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                }>>;
            }, {
                recordFormat: z.ZodLiteral<"application/json">;
                tableName: z.ZodString;
                userIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                    type: z.ZodEnum<["Service"]>;
                    principalId: z.ZodLiteral<"dynamodb.amazonaws.com">;
                }, "strip", z.ZodTypeAny, {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                }, {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                }>>>;
                dynamodb: z.ZodEffects<z.ZodObject<Omit<{
                    ApproximateCreationDateTime: z.ZodOptional<z.ZodNumber>;
                    Keys: z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodAny>>;
                    NewImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    OldImage: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
                    SequenceNumber: z.ZodString;
                    SizeBytes: z.ZodNumber;
                    StreamViewType: z.ZodEnum<["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]>;
                }, "SequenceNumber" | "StreamViewType">, "strip", z.ZodTypeAny, {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }, {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }>, {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }, {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                }>;
            }>, "eventVersion" | "eventSourceARN">, "strip", z.ZodTypeAny, {
                eventSource: "aws:dynamodb";
                eventID: string;
                eventName: "INSERT" | "MODIFY" | "REMOVE";
                awsRegion: string;
                dynamodb: {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                };
                recordFormat: "application/json";
                tableName: string;
                userIdentity?: {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                } | null | undefined;
            }, {
                eventSource: "aws:dynamodb";
                eventID: string;
                eventName: "INSERT" | "MODIFY" | "REMOVE";
                awsRegion: string;
                dynamodb: {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                };
                recordFormat: "application/json";
                tableName: string;
                userIdentity?: {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                } | null | undefined;
            }>>;
        }>, "strip", z.ZodTypeAny, {
            data: {
                eventSource: "aws:dynamodb";
                eventID: string;
                eventName: "INSERT" | "MODIFY" | "REMOVE";
                awsRegion: string;
                dynamodb: {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                };
                recordFormat: "application/json";
                tableName: string;
                userIdentity?: {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                } | null | undefined;
            };
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        }, {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        }>;
    }>, "strip", z.ZodTypeAny, {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: {
                eventSource: "aws:dynamodb";
                eventID: string;
                eventName: "INSERT" | "MODIFY" | "REMOVE";
                awsRegion: string;
                dynamodb: {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                };
                recordFormat: "application/json";
                tableName: string;
                userIdentity?: {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                } | null | undefined;
            };
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }, {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: {
                eventSource: "aws:dynamodb";
                eventID: string;
                eventName: "INSERT" | "MODIFY" | "REMOVE";
                awsRegion: string;
                dynamodb: {
                    Keys: Record<string, Record<string, any>>;
                    SizeBytes: number;
                    ApproximateCreationDateTime?: number | undefined;
                    NewImage?: Record<string, any> | undefined;
                    OldImage?: Record<string, any> | undefined;
                };
                recordFormat: "application/json";
                tableName: string;
                userIdentity?: {
                    type: "Service";
                    principalId: "dynamodb.amazonaws.com";
                } | null | undefined;
            };
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }[];
}, {
    Records: {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }[];
}>;
/**
 * Zod schema for Kinesis Data Stream event
 *
 * @example
 * ```json
 * {
 *   "Records": [
 *     {
 *       "kinesis": {
 *         "kinesisSchemaVersion": "1.0",
 *         "partitionKey": "1",
 *         "sequenceNumber": "49590338271490256608559692538361571095921575989136588898",
 *         "data": "SGVsbG8sIHRoaXMgaXMgYSB0ZXN0Lg==",
 *         "approximateArrivalTimestamp": 1545084650.987
 *       },
 *       "eventSource": "aws:kinesis",
 *       "eventVersion": "1.0",
 *       "eventID": "shardId-000000000006:49590338271490256608559692538361571095921575989136588898",
 *       "eventName": "aws:kinesis:record",
 *       "invokeIdentityArn": "arn:aws:iam::123456789012:role/lambda-role",
 *       "awsRegion": "us-east-2",
 *       "eventSourceARN": "arn:aws:kinesis:us-east-2:123456789012:stream/lambda-stream"
 *     },
 *     {
 *       "kinesis": {
 *         "kinesisSchemaVersion": "1.0",
 *         "partitionKey": "1",
 *         "sequenceNumber": "49590338271490256608559692540925702759324208523137515618",
 *         "data": "VGhpcyBpcyBvbmx5IGEgdGVzdC4=",
 *         "approximateArrivalTimestamp": 1545084711.166
 *       },
 *       "eventSource": "aws:kinesis",
 *       "eventVersion": "1.0",
 *       "eventID": "shardId-000000000006:49590338271490256608559692540925702759324208523137515618",
 *       "eventName": "aws:kinesis:record",
 *       "invokeIdentityArn": "arn:aws:iam::123456789012:role/lambda-role",
 *       "awsRegion": "us-east-2",
 *       "eventSourceARN": "arn:aws:kinesis:us-east-2:123456789012:stream/lambda-stream"
 *     }
 *   ]
 * }
 *```
 * @see {@link types.KinesisDataStreamEvent | KinesisDataStreamEvent}
 * @see {@link https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-event-example}
 *
 */
declare const KinesisDataStreamSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventSource: z.ZodLiteral<"aws:kinesis">;
        eventVersion: z.ZodString;
        eventID: z.ZodString;
        eventName: z.ZodLiteral<"aws:kinesis:record">;
        awsRegion: z.ZodString;
        invokeIdentityArn: z.ZodString;
        eventSourceARN: z.ZodString;
        kinesis: z.ZodObject<{
            kinesisSchemaVersion: z.ZodString;
            partitionKey: z.ZodString;
            sequenceNumber: z.ZodString;
            approximateArrivalTimestamp: z.ZodNumber;
            data: z.ZodEffects<z.ZodString, any, string>;
        }, "strip", z.ZodTypeAny, {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        }, {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        };
    }, {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
            data?: any;
        };
    }[];
}, {
    Records: {
        eventSource: "aws:kinesis";
        eventVersion: string;
        eventID: string;
        eventName: "aws:kinesis:record";
        awsRegion: string;
        invokeIdentityArn: string;
        eventSourceARN: string;
        kinesis: {
            data: string;
            kinesisSchemaVersion: string;
            partitionKey: string;
            sequenceNumber: string;
            approximateArrivalTimestamp: number;
        };
    }[];
}>;
export { KinesisDataStreamRecord, KinesisDataStreamRecordPayload, KinesisDataStreamSchema, KinesisDynamoDBStreamSchema, };
//# sourceMappingURL=kinesis.d.ts.map