import { z } from 'zod';
/**
 * Zod schema for a SES record from an SES event.
 */
declare const SesRecordSchema: z.ZodObject<{
    eventSource: z.ZodLiteral<"aws:ses">;
    eventVersion: z.ZodString;
    ses: z.ZodObject<{
        mail: z.ZodObject<{
            timestamp: z.ZodString;
            source: z.ZodString;
            messageId: z.ZodString;
            destination: z.ZodArray<z.ZodString, "many">;
            headersTruncated: z.ZodBoolean;
            headers: z.ZodArray<z.ZodObject<{
                name: z.ZodString;
                value: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                value: string;
                name: string;
            }, {
                value: string;
                name: string;
            }>, "many">;
            commonHeaders: z.ZodObject<{
                from: z.ZodArray<z.ZodString, "many">;
                to: z.ZodArray<z.ZodString, "many">;
                cc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                bcc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                sender: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                'reply-to': z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                returnPath: z.ZodString;
                messageId: z.ZodString;
                date: z.ZodString;
                subject: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            }, {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        }, {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        }>;
        receipt: z.ZodObject<{
            timestamp: z.ZodString;
            processingTimeMillis: z.ZodNumber;
            recipients: z.ZodArray<z.ZodString, "many">;
            spamVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            virusVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            spfVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dmarcVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dkimVerdict: z.ZodObject<{
                status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
            }, "strip", z.ZodTypeAny, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }, {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            }>;
            dmarcPolicy: z.ZodEnum<["none", "quarantine", "reject"]>;
            action: z.ZodObject<{
                type: z.ZodEnum<["Lambda"]>;
                invocationType: z.ZodLiteral<"Event">;
                functionArn: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            }, {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        }, {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        mail: {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    }, {
        mail: {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    }>;
}, "strip", z.ZodTypeAny, {
    eventSource: "aws:ses";
    eventVersion: string;
    ses: {
        mail: {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    };
}, {
    eventSource: "aws:ses";
    eventVersion: string;
    ses: {
        mail: {
            headers: {
                value: string;
                name: string;
            }[];
            messageId: string;
            source: string;
            timestamp: string;
            destination: string[];
            headersTruncated: boolean;
            commonHeaders: {
                date: string;
                messageId: string;
                from: string[];
                to: string[];
                returnPath: string;
                subject: string;
                cc?: string[] | undefined;
                bcc?: string[] | undefined;
                sender?: string[] | undefined;
                'reply-to'?: string[] | undefined;
            };
        };
        receipt: {
            timestamp: string;
            processingTimeMillis: number;
            recipients: string[];
            spamVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            virusVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            spfVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dkimVerdict: {
                status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
            };
            dmarcPolicy: "none" | "quarantine" | "reject";
            action: {
                type: "Lambda";
                invocationType: "Event";
                functionArn: string;
            };
        };
    };
}>;
/**
 * Zod schema for SES events from AWS.
 *
 * @example
 * ```json
 * {
 *   "Records": [
 *     {
 *       "eventVersion": "1.0",
 *       "ses": {
 *         "mail": {
 *           "commonHeaders": {
 *             "from": [
 *               "Jane Doe <janedoe@example.com>"
 *             ],
 *             "to": [
 *               "johndoe@example.com"
 *             ],
 *             "returnPath": "janedoe@example.com",
 *             "messageId": "<0123456789example.com>",
 *             "date": "Wed, 7 Oct 2015 12:34:56 -0700",
 *             "subject": "Test Subject"
 *           },
 *           "source": "janedoe@example.com",
 *           "timestamp": "1970-01-01T00:00:00.000Z",
 *           "destination": [
 *             "johndoe@example.com"
 *           ],
 *           "headers": [
 *             {
 *               "name": "Return-Path",
 *               "value": "<janedoe@example.com>"
 *             },
 *             {
 *               "name": "Received",
 *               "value": "from mailer.example.com (mailer.example.com [203.0.113.1]) by ..."
 *             },
 *             {
 *               "name": "DKIM-Signature",
 *               "value": "v=1; a=rsa-sha256; c=relaxed/relaxed; d=example.com; s=example; ..."
 *             },
 *             {
 *               "name": "MIME-Version",
 *               "value": "1.0"
 *             },
 *             {
 *               "name": "From",
 *               "value": "Jane Doe <janedoe@example.com>"
 *             },
 *             {
 *               "name": "Date",
 *               "value": "Wed, 7 Oct 2015 12:34:56 -0700"
 *             },
 *             {
 *               "name": "Message-ID",
 *               "value": "<0123456789example.com>"
 *             },
 *             {
 *               "name": "Subject",
 *               "value": "Test Subject"
 *             },
 *             {
 *               "name": "To",
 *               "value": "johndoe@example.com"
 *             },
 *             {
 *               "name": "Content-Type",
 *               "value": "text/plain; charset=UTF-8"
 *             }
 *           ],
 *           "headersTruncated": false,
 *           "messageId": "o3vrnil0e2ic28tr"
 *         },
 *         "receipt": {
 *           "recipients": [
 *             "johndoe@example.com"
 *           ],
 *           "timestamp": "1970-01-01T00:00:00.000Z",
 *           "spamVerdict": {
 *             "status": "PASS"
 *           },
 *           "dkimVerdict": {
 *             "status": "PASS"
 *           },
 *           "dmarcPolicy": "reject",
 *           "processingTimeMillis": 574,
 *           "action": {
 *             "type": "Lambda",
 *             "invocationType": "Event",
 *             "functionArn": "arn:aws:lambda:us-west-2:012345678912:function:Example"
 *           },
 *           "dmarcVerdict": {
 *             "status": "PASS"
 *           },
 *           "spfVerdict": {
 *             "status": "PASS"
 *           },
 *           "virusVerdict": {
 *             "status": "PASS"
 *           }
 *         }
 *       },
 *       "eventSource": "aws:ses"
 *     }
 *   ]
 * }
 * ```
 *
 * @see {@link types.SesEvent | SesEvent}
 * @see {@link https://docs.aws.amazon.com/ses/latest/dg/receiving-email-notifications-examples.html}
 */
declare const SesSchema: z.ZodObject<{
    Records: z.ZodArray<z.ZodObject<{
        eventSource: z.ZodLiteral<"aws:ses">;
        eventVersion: z.ZodString;
        ses: z.ZodObject<{
            mail: z.ZodObject<{
                timestamp: z.ZodString;
                source: z.ZodString;
                messageId: z.ZodString;
                destination: z.ZodArray<z.ZodString, "many">;
                headersTruncated: z.ZodBoolean;
                headers: z.ZodArray<z.ZodObject<{
                    name: z.ZodString;
                    value: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    value: string;
                    name: string;
                }, {
                    value: string;
                    name: string;
                }>, "many">;
                commonHeaders: z.ZodObject<{
                    from: z.ZodArray<z.ZodString, "many">;
                    to: z.ZodArray<z.ZodString, "many">;
                    cc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    bcc: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    sender: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    'reply-to': z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    returnPath: z.ZodString;
                    messageId: z.ZodString;
                    date: z.ZodString;
                    subject: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                }, {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                }>;
            }, "strip", z.ZodTypeAny, {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            }, {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            }>;
            receipt: z.ZodObject<{
                timestamp: z.ZodString;
                processingTimeMillis: z.ZodNumber;
                recipients: z.ZodArray<z.ZodString, "many">;
                spamVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                virusVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                spfVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dmarcVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dkimVerdict: z.ZodObject<{
                    status: z.ZodEnum<["PASS", "FAIL", "GRAY", "PROCESSING_FAILED"]>;
                }, "strip", z.ZodTypeAny, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }, {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                }>;
                dmarcPolicy: z.ZodEnum<["none", "quarantine", "reject"]>;
                action: z.ZodObject<{
                    type: z.ZodEnum<["Lambda"]>;
                    invocationType: z.ZodLiteral<"Event">;
                    functionArn: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                }, {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            }, {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            }>;
        }, "strip", z.ZodTypeAny, {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        }, {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        }>;
    }, "strip", z.ZodTypeAny, {
        eventSource: "aws:ses";
        eventVersion: string;
        ses: {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }, {
        eventSource: "aws:ses";
        eventVersion: string;
        ses: {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    Records: {
        eventSource: "aws:ses";
        eventVersion: string;
        ses: {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }[];
}, {
    Records: {
        eventSource: "aws:ses";
        eventVersion: string;
        ses: {
            mail: {
                headers: {
                    value: string;
                    name: string;
                }[];
                messageId: string;
                source: string;
                timestamp: string;
                destination: string[];
                headersTruncated: boolean;
                commonHeaders: {
                    date: string;
                    messageId: string;
                    from: string[];
                    to: string[];
                    returnPath: string;
                    subject: string;
                    cc?: string[] | undefined;
                    bcc?: string[] | undefined;
                    sender?: string[] | undefined;
                    'reply-to'?: string[] | undefined;
                };
            };
            receipt: {
                timestamp: string;
                processingTimeMillis: number;
                recipients: string[];
                spamVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                virusVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                spfVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dkimVerdict: {
                    status: "PASS" | "FAIL" | "GRAY" | "PROCESSING_FAILED";
                };
                dmarcPolicy: "none" | "quarantine" | "reject";
                action: {
                    type: "Lambda";
                    invocationType: "Event";
                    functionArn: string;
                };
            };
        };
    }[];
}>;
export { SesSchema, SesRecordSchema };
//# sourceMappingURL=ses.d.ts.map